@@ -25,7 +25,7 @@ __version__ = "$Id: 0.py 2265 2010-02-21 19:16:26Z v13 $"
 import os
 import pickle
 
-version = "0.3"
+version = "0.4"
 
 try:
     from glib import get_user_config_dir
@@ -187,7 +187,7 @@ class Config:
 
 	dt0=self.load_all()
 
-	if not dt0['data'].has_key(self.id):
+	if dt0==None or not dt0['data'].has_key(self.id):
 	    return
 
 	dt=dt0['data'][self.id]
