@@ -112,7 +112,7 @@ class WinConfig(StackableWindow):
 	self.buttonRequireLongpress=but
 	vbox.add(but)
 
-	#self.igw.connect('long-press', self.slotLongpress)
+	self.igw.connect('long-press', self.slotLongpress)
 	self.igw.connect('click', self.slotLongpress)
 
 	self.ignore_toggle=False
@@ -237,10 +237,11 @@ class WinConfig(StackableWindow):
 	r=dialog.run()
 
 	if r==gtk.RESPONSE_OK:
-	    cur=selector.get_current_text()
-	    if cur=='None':
+	    idx2=selector.get_active(0)
+	    if idx2<1:
 		app=None
 	    else:
+		cur=lst[idx2-1]
 		for i in aps:
 		    if aps[i]['name']==cur:
 			app=aps[i]
